@@ -16,13 +16,9 @@
 
 $docroot ??= ($_SERVER['DOCUMENT_ROOT'] ?: '/usr/local/emhttp');
 require_once "$docroot/webGui/include/Helpers.php";
-require_once "$docroot/webGui/include/SriovHelpers.php";
-
 
 $pci_device_changes = comparePCIData();
-$sriov = json_decode(getSriovInfoJson(true), true);
 $pcierror = false;
-$srioverror = false;
 $pci_addresses = [];
 foreach ($argv as $arg) {
 if (preg_match('/"host"\s*:\s*"([^"]+)"/', $arg, $matches)) {
@@ -33,16 +29,7 @@ foreach($pci_addresses as $pciid) {
 if (isset($pci_device_changes[$pciid])) {
     $pcierror = true;
     }
-    // Check if device is an SR-IOV PF with VFs defined
-    $check_id = $pciid;
-    if (!preg_match('/^[0-9a-fA-F]{4}:/', $check_id)) {
-        $check_id = "0000:" . $check_id;
-    }
-    if (isset($sriov[$check_id]) && !empty($sriov[$check_id]['vfs'])) {
-        $srioverror = true;
-    }
 }
-if ($pcierror) { echo $pcierror == true ? "yes" : "no"; exit; }
-if ($srioverror) { echo $srioverror == true ? "sriov" : "no"; exit; }
-echo "no";
+
+echo $pcierror == true ? "yes" : "no";
 ?>
\ No newline at end of file
